@@ -17,7 +17,9 @@ class SensorV3(EntityV3):
 
         :rtype: ``bool``
         """
-        return self._entity_data["setting"].get("instantTrigger", False)
+        return self._system.entity_data[self._serial]["setting"].get(
+            "instantTrigger", False
+        )
 
     @property
     def triggered(self) -> bool:
@@ -34,7 +36,9 @@ class SensorV3(EntityV3):
             EntityTypes.smoke,
             EntityTypes.temperature,
         ):
-            return self._entity_data["status"].get("triggered", False)
+            return self._system.entity_data[self._serial]["status"].get(
+                "triggered", False
+            )
 
         return False
 
@@ -49,4 +53,4 @@ class SensorV3(EntityV3):
         if self.type != EntityTypes.temperature:
             raise AttributeError("Non-temperature sensor cannot have a temperature")
 
-        return self._entity_data["status"]["temperature"]
+        return self._system.entity_data[self._serial]["status"]["temperature"]
