@@ -2,20 +2,18 @@
 import asyncio
 from dataclasses import InitVar, dataclass, field
 from datetime import datetime
-import logging
 from typing import Awaitable, Callable, Optional
 from urllib.parse import urlencode
 
 from socketio import AsyncClient
 from socketio.exceptions import ConnectionError as ConnError, SocketIOError
 
+from simplipy.const import LOGGER
 from simplipy.entity import EntityTypes
 from simplipy.errors import WebsocketError
 from simplipy.util.dt import utc_from_timestamp
 
-_LOGGER = logging.getLogger(__name__)
-
-API_URL_BASE: str = "wss://api.simplisafe.com/socket.io"
+API_URL_BASE = "wss://api.simplisafe.com/socket.io"
 
 DEFAULT_WATCHDOG_TIMEOUT = 900
 
@@ -109,7 +107,7 @@ class WebsocketEvent:  # pylint: disable=too-many-instance-attributes
         if event_cid in EVENT_MAPPING:
             object.__setattr__(self, "event_type", EVENT_MAPPING[event_cid])
         else:
-            _LOGGER.warning(
+            LOGGER.warning(
                 'Encountered unknown websocket event type: %s ("%s"). Please report it '
                 "at https://github.com/bachya/simplisafe-python/issues.",
                 event_cid,
@@ -123,7 +121,7 @@ class WebsocketEvent:  # pylint: disable=too-many-instance-attributes
             try:
                 object.__setattr__(self, "sensor_type", EntityTypes(self.sensor_type))
             except ValueError:
-                _LOGGER.warning(
+                LOGGER.warning(
                     'Encountered unknown entity type: %s ("%s"). Please report it at'
                     "https://github.com/home-assistant/home-assistant/issues.",
                     self.sensor_type,
@@ -159,7 +157,7 @@ class WebsocketWatchdog:  # pylint: disable=too-few-public-methods
         self._action: Callable[..., Awaitable] = action
         self._loop = asyncio.get_event_loop()
         self._timer_task: Optional[asyncio.TimerHandle] = None
-        self._timeout: int = timeout_seconds
+        self._timeout = timeout_seconds
 
     def cancel(self):
         """Cancel the watchdog."""
@@ -169,12 +167,12 @@ class WebsocketWatchdog:  # pylint: disable=too-few-public-methods
 
     async def on_expire(self):
         """Log and act when the watchdog expires."""
-        _LOGGER.info("Watchdog expired – calling %s", self._action.__name__)
+        LOGGER.info("Watchdog expired – calling %s", self._action.__name__)
         await self._action()
 
     async def trigger(self):
         """Trigger the watchdog."""
-        _LOGGER.info("Watchdog triggered – sleeping for %s seconds", self._timeout)
+        LOGGER.info("Watchdog triggered – sleeping for %s seconds", self._timeout)
 
         if self._timer_task:
             self._timer_task.cancel()
@@ -245,7 +243,7 @@ class Websocket:
             self._sync_disconnect_handler()
             self._sync_disconnect_handler = None
 
-    def async_on_connect(self, target: Callable[..., Awaitable]) -> None:  # noqa: D202
+    def async_on_connect(self, target: Callable[..., Awaitable]) -> None:
         """Define a coroutine to be called when connecting.
 
         :param target: A coroutine
@@ -259,7 +257,7 @@ class Websocket:
 
         self._sio.on("connect", _async_on_connect)
 
-    def on_connect(self, target: Callable) -> None:  # noqa: D202
+    def on_connect(self, target: Callable) -> None:
         """Define a synchronous method to be called when connecting.
 
         :param target: A synchronous function
@@ -289,7 +287,7 @@ class Websocket:
         """
         self._sync_disconnect_handler = target
 
-    def async_on_event(self, target: Callable[..., Awaitable]) -> None:  # noqa: D202
+    def async_on_event(self, target: Callable[..., Awaitable]) -> None:
         """Define a coroutine to be called an event is received.
 
         The couroutine will have a ``data`` parameter that contains the raw data from
@@ -307,7 +305,7 @@ class Websocket:
 
         self._sio.on("event", _async_on_event, namespace=self._namespace)
 
-    def on_event(self, target: Callable) -> None:  # noqa: D202
+    def on_event(self, target: Callable) -> None:
         """Define a synchronous method to be called when an event is received.
 
         The method will have a ``data`` parameter that contains the raw data from the
